# -*- coding: utf-8 -*-

import sys
import time

def print_progress(iteration, total_iterations, update_interval_sec = 1.0):
    global _time_started, _time_updated
    
    t = time.time()
    i = iteration
    if i==0:
        _time_started = _time_updated = t
    elif ((t - _time_updated) > update_interval_sec) or i == (total_iterations - 1) :
        _time_updated = t
        t_elapsed = t - _time_started    
        i_ = i + 1
        progress = i_ / total_iterations
        progress_pct = 100 * progress
        t_est_total = t_elapsed / progress
        t_est_remained = t_est_total - t_elapsed
        sys.stdout.write(f'\rProgress:{progress_pct: 5.2f} % ' \
                         + f' | Processed:{i_: d}/{total_iterations: d} ' \
                         + f' | Elapsed: {t_elapsed: 8.0f} sec' \
                         + f' | Est total: {t_est_total: 8.0f} sec' \
                         + f' | Est remained: {t_est_remained: 8.0f} sec' \
                        )
        sys.stdout.flush()
    if i == (total_iterations - 1):
        print()
        
### Example ###
if __name__ == "__main__":
    total_iterations = 100
    for i in range(total_iterations):
        print_progress(i, total_iterations)


from setuptools import setup
from codecs import open
from os import path
import re

package_name = 'pyminyus'

# Read version from __init__.py file
root_dir = path.abspath(path.dirname(__file__))
with open(path.join(root_dir, package_name, '__init__.py')) as f:
    init_text = f.read()
    version = re.search(r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)

setup(
    name=package_name,
    packages=[package_name],
    version=version,
    license='MIT',
    author='Yusuke Minami',
    author_email='me@minyus.github.com',
    url='https://github.com/Minyus/pyminyus',
	description='Python utility.',
	install_requires=[
    ],
	keywords='minyus',
	zip_safe=False,
    test_suite='tests',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Natural Language :: English',
        "License :: OSI Approved :: MIT License",
        'Programming Language :: Python :: 3.6',
        "Operating System :: OS Independent"
    ])
